/****************************************************************************
 File name:  rational.c
 Author:     Joe Bloggs
 Date:       8/31/09
 Class:      CS300
 Assignment: Rational
 Purpose:    This is the implementation file for each of the rational
             functions associated with the rational module.
****************************************************************************/


#include <stdio.h>
#include "../include/rational.h"

/****************************************************************************
 Function:    rationalPrint

 Description: Outputs a fraction in the form
              numerator / denominator to the screen

 Parameters:  sRational - a fraction to be printed

 Returned:    None
****************************************************************************/


void rationalPrint (Rational sRational)
{

  printf ("%d / %d", sRational.numerator, sRational.denominator);
}

/****************************************************************************
 Function:    rationalSet

 Description: Initializes a fraction to the values of the numerator and
              denominator passed in.

 Parameters:  sRational   - a fraction
              numerator   - numerator initialization value
							denominator - denominator initialization value

 Returned:    None
****************************************************************************/


void rationalSet (Rational *psRational, int numerator, int denominator)
{
	psRational->numerator = numerator;
	psRational->denominator = denominator;
}

/****************************************************************************
 Function:    rationalIsEqual

 Description: Compares two fractions returning a value of true if the
              numerators and denominators of both fractions are the same.

 Parameters:  sRational1 - first fraction used in comparison
              sRational2 - second fraction used in comparison

 Returned:    true if objects are equal; else, false
****************************************************************************/


int rationalIsEqual (Rational sRational1, Rational sRational2)
{
  return ((sRational1.numerator == sRational2.numerator) &&
          (sRational1.denominator == sRational2.denominator));
}

/****************************************************************************
 Function:    rationalMultiply

 Description: Multiples the numerators and denominators of two fractions.

 Parameters:  sRational1 - first rational number
              sRational2 - second rational number

 Returned:    A fraction that contains the result of the multiplication.
****************************************************************************/

Rational rationalMultiply (Rational sRational1, Rational sRational2)
{
  Rational sFraction;

  rationalSet (&sFraction, 0, 0);
  sFraction.numerator = sRational1.numerator * sRational2.numerator;
  sFraction.denominator = sRational1.denominator * sRational2.denominator;

  return sFraction;
}
